@@ -8,7 +8,7 @@
 	grid = list()
 	for (i in seq(along = object$data)) {
 		d = object$data[[i]]
-		raw = gstat.formula(d$formula, d$locations, eval(d$data))
+		raw = gstat.formula(d$formula, d$data)
 		y[[i]] = raw$y
 		locations[[i]] = raw$locations
 		X[[i]] = raw$X
